@@ -31,28 +31,33 @@ class Context:
     logging.getLogger().vault.clear()
 
   def reset(self, workflow_name, session):
-    logging.getLogger().log_section("WORKFLOW",
-                                    f"Started {workflow_name} / {session}")
-    logging.getLogger().vault.clear()
-    self._configure_logger(workflow_name, session)
-    self.set_workflow_config(workflow_name)
-    self.workspace = Workspace(workspacedir=self.workspacedir,
-                               workflow=workflow_name,
-                               session=session)
-    self.history = History(filename=os.path.join(self.histdir,
-                                                 f"{workflow_name}.db"),
-                           workflow=workflow_name,
-                           session=session,
-                           params=self.configmgr.workflow_config)
-    self.history.enter()
-    self.install_packages()
-    return self
+    try:
+      logging.getLogger().log_section("WORKFLOW",
+                                      f"Started {workflow_name} / {session}")
+      logging.getLogger().vault.clear()
+      self._configure_logger(workflow_name, session)
+      self.set_workflow_config(workflow_name)
+      self.workspace = Workspace(workspacedir=self.workspacedir,
+                                 workflow=workflow_name,
+                                 session=session)
+      history_path = os.path.join(self.histdir, f"{workflow_name}.db")
+      self.history = History(filename=history_path,
+                             workflow=workflow_name,
+                             session=session,
+                             params=self.configmgr.workflow_config)
+      self.history.enter()
+      self.install_packages()
+      return self
+    except Exception as err:
+      ErrorHandler().handle_error(workflow_name,
+                                  session,
+                                  err.__class__,
+                                  str(err))
 
-  def exit(self, session, kind, value, traceback, exit_code):
-    logging.info(f"[+] Workflow ended with code: {exit_code}")
+  def exit(self, name, session, kind, value):
     self.workspace.delete()
     self.history.exit(kind, value)
-    self.handle_error(kind, value, traceback)
+    ErrorHandler().handle_error(name, session, kind, value)
     self.logger.remove_file_handler(session)
 
   def _configure_logger(self, workflow_name, session):
@@ -89,6 +94,3 @@ class Context:
       list(map(logging.getLogger().vault.add, secrets))
     except IndexError as err:
       raise LaboroError(f"UnknownMethodError: Unknown method {instance.__class__.__name__}.{action}") from err
-
-  def handle_error(self, kind, value, traceback):
-    ErrorHandler().handle_error(kind, value, traceback)
