@@ -9,11 +9,6 @@ from prettytable import PrettyTable
 class History:
   """The History class provides all methods necessary to manage execution history. History file is a sqlite database.
 
-  Entering the the runtime context using the ``with`` statement will automatically create the history database as needed, record the session with all its parameters in the database.
-  The workflow session start time will also be recorded.
-
-  Before exiting the runtime context, the workflow end time, its duration and its exit code will be recorded in the history database.
-
   Arguments:
       filename: A string specifying the full path to the history file to use
       workflow: A string defining the workflow name.
@@ -45,28 +40,6 @@ class History:
     self.session = session
     self.retention = retention
 
-  def __enter__(self):
-    self._create_db()
-    self._purge_history()
-
-    record = [self.workflow,
-              self.session,
-              self.start,
-              self.params]
-    with sqlite3.connect(self.hist_filename) as conn:
-      cursor = conn.cursor()
-      cursor.execute("insert into executions (workflow, session, start, params) values (?, ?, ?, ?)", record)
-      conn.commit()
-
-  def __exit__(self, kind, value, traceback):
-    exit_code = 0
-    if kind == SystemExit:
-      if value.code is not None:
-        exit_code = value.code
-    elif kind is not None:
-      exit_code = f"{kind.__name__}: {value}"
-    self._end_exec(exit_code)
-
   def _create_db(self):
     logging.info(f"[+] Checking history database: {self.hist_filename}")
     if not os.path.exists(self.hist_filename):
@@ -105,6 +78,45 @@ class History:
       cursor.execute("delete from executions where session not in (select session from executions order by end DESC limit ?)", [self.retention])
       conn.commit()
 
+  def _format_time_delta(self, tdelta):
+    """Take a timedelta object and formats it for humans.
+    From https://gist.github.com/dhrrgn/7255361
+    """
+    delta = dict(days=tdelta.days)
+    delta["hrs"], rem = divmod(tdelta.seconds, 3600)
+    delta["min"], delta["sec"] = divmod(rem, 60)
+    if delta["min"] == 0:
+      fmt = "{sec} sec"
+    elif delta["hrs"] == 0:
+      fmt = "{min} min {sec} sec"
+    elif delta["days"] == 0:
+      fmt = "{hrs} hr(s) {min} min {sec} sec"
+    else:
+      fmt = "{days} day(s) {hrs} hr(s) {min} min {sec} sec"
+    return fmt.format(**delta)
+
+  def enter(self):
+    self._create_db()
+    self._purge_history()
+
+    record = [self.workflow,
+              self.session,
+              self.start,
+              self.params]
+    with sqlite3.connect(self.hist_filename) as conn:
+      cursor = conn.cursor()
+      cursor.execute("insert into executions (workflow, session, start, params) values (?, ?, ?, ?)", record)
+      conn.commit()
+
+  def exit(self, kind, value):
+    exit_code = 0
+    if kind == SystemExit:
+      if value.code is not None:
+        exit_code = value.code
+    elif kind is not None:
+      exit_code = f"{kind.__name__}: {value}"
+    self._end_exec(exit_code)
+
   def read_history(self, workflow, num_exec):
     """Displays last ``num_exec`` history lines for specified ``workflow``.
 
@@ -128,20 +140,3 @@ class History:
       cursor.execute("select * from executions where workflow=? order by start desc limit=?", [workflow, num_exec])
       table.add_rows(cursor.fetchall())
       return table.get_string()
-
-  def _format_time_delta(self, tdelta):
-    """Take a timedelta object and formats it for humans.
-    From https://gist.github.com/dhrrgn/7255361
-    """
-    delta = dict(days=tdelta.days)
-    delta["hrs"], rem = divmod(tdelta.seconds, 3600)
-    delta["min"], delta["sec"] = divmod(rem, 60)
-    if delta["min"] == 0:
-      fmt = "{sec} sec"
-    elif delta["hrs"] == 0:
-      fmt = "{min} min {sec} sec"
-    elif delta["days"] == 0:
-      fmt = "{hrs} hr(s) {min} min {sec} sec"
-    else:
-      fmt = "{days} day(s) {hrs} hr(s) {min} min {sec} sec"
-    return fmt.format(**delta)
