@@ -30,7 +30,6 @@ class Workflow:
   """
   def __init__(self, name, context):
     self.name = name
-    self.store = dict()
     self.session = str(uuid.uuid4())
     self.context = context.reset(self.name, self.session)
 
@@ -38,17 +37,7 @@ class Workflow:
     return self
 
   def __exit__(self, kind, value, traceback):
-    exit_msg = "Exiting"
-    if value is not None:
-      exit_msg += f" with {value}"
-    logging.getLogger().log_section("WORKFLOW", exit_msg)
-    exit_code = 0
-    if kind == SystemExit:
-      if value.code is not None:
-        exit_code = value.code
-    elif kind is not None:
-      exit_code = f"{kind.__name__}: {value}"
-    self.context.exit(self.session, kind, value, traceback, exit_code)
+    self.context.exit(self.name, self.session, kind, value)
 
   def _instantiate(self, module, cls, args):
     logging.info(f"[+] Object instantiation: {module}.{cls}")
